# SenSplit
This python package helps to splits a sensor dataset (in Pandas DataFrame format) into train and test sets.

-----------------------------------------
## Installation 
Install SenSplit from PyPI (recommended):
```sh
pip install sensplit
```
- **Alternatively: install SenSplit from the GitHub source:**

First, clone SenSplit using `git`:

```sh
git clone https://github.com/mmalekzadeh/sensplit
```

 Then, `cd` to the SenSplit folder and run the install command:
```sh
cd sensplit
python setup.py install
```
